@@ -122,12 +122,10 @@ parseRayStation <- function(x, planInfo=FALSE, courseAsID=FALSE) {
             return(NULL)
         }
         
-        con <- textConnection(strct[dvhStart:length(strct)])
-        dvh <- data.matrix(read.table(con,
+        dvh <- data.matrix(read.table(text=strct[dvhStart:length(strct)],
                                       header=FALSE, stringsAsFactors=FALSE,
                                       colClasses=rep("numeric", 2),
                                       comment.char="", nrows=dvhLen))
-        close(con)
 
         ## rename columns
         colnames(dvh) <- c("dose", "volumeRel")
